@@ -91,6 +91,13 @@ static GObjectClass *parent_klass;
 
 static void gog_object_set_id (GogObject *obj, unsigned id);
 
+static void
+gog_object_parent_finalized (GogObject *obj)
+{
+	obj->parent = NULL;
+	g_object_unref (obj);
+}
+
 static void
 gog_object_finalize (GObject *gobj)
 {
@@ -99,7 +106,7 @@ gog_object_finalize (GObject *gobj)
 	g_free (obj->user_name); obj->user_name = NULL;
 	g_free (obj->auto_name); obj->auto_name = NULL;
 
-	g_slist_foreach (obj->children, (GFunc) g_object_unref, NULL);
+	g_slist_foreach (obj->children, (GFunc) gog_object_parent_finalized, NULL);
 	g_slist_free (obj->children);
 	obj->children = NULL;
 
@@ -363,7 +370,7 @@ cb_update_editor (GogObject *gobj, ObjectPrefState *state)
 static void
 cb_chart_position_changed (GtkWidget *spin, ObjectPrefState *state)
 {
-	g_object_set (G_OBJECT (state->gobj), gtk_widget_get_name (spin),
+	g_object_set (G_OBJECT (state->gobj), gtk_buildable_get_name (GTK_BUILDABLE (spin)),
 		      (int) gtk_spin_button_get_value (GTK_SPIN_BUTTON (spin)), NULL);
 }
 
