@@ -13,9 +13,13 @@
 
 GSF_CLASS (GOUndo, go_undo, NULL, NULL, G_TYPE_OBJECT)
 
-/*
- * Execute the stored undo operation.  Note: the supplied data item is
- * supplied to the undo operation.  It is meant not to affect the undo
+/**
+ * go_undo_undo_with_data
+ * @u: undo object
+ * @data: user data
+ *
+ * Execute the stored undo operation.  @data is supplied to the undo
+ * operation as an extra argument.  It is meant not to affect the undo
  * operation in any way, but rather supply a context through which
  * progress and errors can be reported.
  */
@@ -24,12 +28,18 @@ go_undo_undo_with_data (GOUndo *u, gpointer data)
 {
 	GOUndoClass *uc;
 
-	g_return_if_fail (IS_GO_UNDO (u));
+	g_return_if_fail (GO_IS_UNDO (u));
 
-	uc = G_TYPE_INSTANCE_GET_CLASS (u, GO_UNDO_TYPE, GOUndoClass);
+	uc = G_TYPE_INSTANCE_GET_CLASS (u, GO_TYPE_UNDO, GOUndoClass);
 	uc->undo (u, data);
 }
 
+/**
+ * go_undo_undo
+ * @u: undo object
+ *
+ * Execute the stored undo operation.
+ */
 void
 go_undo_undo (GOUndo *u)
 {
@@ -50,14 +60,14 @@ go_undo_undo (GOUndo *u)
 GOUndo *
 go_undo_combine (GOUndo *a, GOUndo *b)
 {
-	g_return_val_if_fail (a == NULL || IS_GO_UNDO (a), NULL);
-	g_return_val_if_fail (b == NULL || IS_GO_UNDO (b), NULL);
+	g_return_val_if_fail (a == NULL || GO_IS_UNDO (a), NULL);
+	g_return_val_if_fail (b == NULL || GO_IS_UNDO (b), NULL);
 
 	if (!a)
 		return b;
 	else if (!b)
 		return a;
-	else if (IS_GO_UNDO_GROUP (a)) {
+	else if (GO_IS_UNDO_GROUP (a)) {
 		go_undo_group_add (GO_UNDO_GROUP (a), b);
 		return a;
 	} else {
@@ -118,21 +128,34 @@ go_undo_group_class_init (GObjectClass *gobject_class)
 }
 
 GSF_CLASS (GOUndoGroup, go_undo_group,
-	   go_undo_group_class_init, go_undo_group_init, GO_UNDO_TYPE)
+	   go_undo_group_class_init, go_undo_group_init, GO_TYPE_UNDO)
 
+/**
+ * go_undo_group_new:
+ *
+ * This function creates a new undo group for compounding undo objects.
+ *
+ * Returns: a new, empty undo group.
+ **/
 GOUndoGroup *
 go_undo_group_new (void)
 {
-	return g_object_new (GO_UNDO_GROUP_TYPE, NULL);
+	return g_object_new (GO_TYPE_UNDO_GROUP, NULL);
 }
 
-/* Takes ownership of u. */
+/**
+ * go_undo_group_add:
+ * @g: undo group
+ * @u: undo object
+ *
+ * This function adds @u to @g.
+ **/
 void
-go_undo_group_add (GOUndoGroup *ug, GOUndo *u)
+go_undo_group_add (GOUndoGroup *g, GOUndo *u)
 {
-	g_return_if_fail (IS_GO_UNDO_GROUP (ug));
-	g_return_if_fail (IS_GO_UNDO (u));
-	g_ptr_array_add (ug->undos, u);
+	g_return_if_fail (GO_IS_UNDO_GROUP (g));
+	g_return_if_fail (GO_IS_UNDO (u));
+	g_ptr_array_add (g->undos, u);
 }
 
 /* ------------------------------------------------------------------------- */
@@ -171,13 +194,26 @@ go_undo_binary_class_init (GObjectClass *gobject_class)
 
 
 GSF_CLASS (GOUndoBinary, go_undo_binary,
-	   go_undo_binary_class_init, NULL, GO_UNDO_TYPE)
+	   go_undo_binary_class_init, NULL, GO_TYPE_UNDO)
 
+/**
+ * go_undo_binary_new:
+ * @a: first argument for undo operation
+ * @b: second argument for undo operation
+ * @undo: function to call with arguments @a and @b for undo.
+ * @fa: optional function to free @a.
+ * @fb: optional function to free @b.
+ *
+ * This function creates a new undo object for undo operations of two
+ * arguments.  (In addition, an undo-time argument is added for context.)
+ *
+ * Returns: a new undo object.
+ **/
 GOUndo *
 go_undo_binary_new (gpointer a, gpointer b, GOUndoBinaryFunc undo,
 		    GFreeFunc fa, GFreeFunc fb)
 {
-	GOUndoBinary *ua = g_object_new (GO_UNDO_BINARY_TYPE, NULL);
+	GOUndoBinary *ua = g_object_new (GO_TYPE_UNDO_BINARY, NULL);
 	ua->a = a;
 	ua->b = b;
 	ua->undo = undo;
@@ -220,12 +256,23 @@ go_undo_unary_class_init (GObjectClass *gobject_class)
 
 
 GSF_CLASS (GOUndoUnary, go_undo_unary,
-	   go_undo_unary_class_init, NULL, GO_UNDO_TYPE)
+	   go_undo_unary_class_init, NULL, GO_TYPE_UNDO)
 
+/**
+ * go_undo_unary_new:
+ * @a: argument for undo operation
+ * @undo: function to call with argument @a for undo.
+ * @fa: optional function to free @a.
+ *
+ * This function creates a new undo object for undo operations of one
+ * argument.  (In addition, an undo-time argument is added for context.)
+ *
+ * Returns: a new undo object.
+ **/
 GOUndo *
 go_undo_unary_new (gpointer a, GOUndoUnaryFunc undo, GFreeFunc fa)
 {
-	GOUndoUnary *ua = g_object_new (GO_UNDO_UNARY_TYPE, NULL);
+	GOUndoUnary *ua = g_object_new (GO_TYPE_UNDO_UNARY, NULL);
 	ua->a = a;
 	ua->undo = undo;
 	ua->disposea = fa;
